# I. INTRODUCTION
`pydata_master` is an all-in-one package for the data operation in a daily basis which contains almost frequently used functions I need.

# II. REFERENCES
## 2.1. How to install this package?
- Using pip to installed pre-builded package on Pypip `pip install pydata_master`
- If you want to use the latest pydata_master version instead of the stable one, you can install it from source with the following command:
`pip install git+https://github.com/thinh-vu/pydata_master.git@main`


## Google services
creds, gc = google_auth('YOUR_PATH_TO_JSON')

# III. APENDICES

![Datetime Frequencies](../main/src/pandas_daterange_freq_list.png)

# IV. 🙋‍♂️ CONTACT INFORMATION
You can contact me at one of my social network profiles:

- 💼 LinkedIn: https://linkedin.com/in/thinh-vu
- :octocat: GitHub: https://github.com/thinh-vu
